"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = tslib_1.__importStar(require("path"));
const playwright_1 = require("playwright");
const SUT = tslib_1.__importStar(require("../index"));
const page_actions_1 = require("../../../page-actions");
describe('get elements with role', () => {
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    beforeEach(() => { });
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    afterEach(async () => { });
    test('should return an empty array when root elements is empty', async () => {
        // Given
        // When
        const result = await SUT.getHandlesWithRole('foobar', []);
        // Then
        expect(Array.isArray(result)).toBe(true);
        expect(result.length).toBe(0);
    });
    test('should return inputs with the role', async () => {
        // Given
        const browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'get-handles-with-role.test.html')}`;
        await page.goto(url);
        // When
        const inputElements = await (0, page_actions_1.querySelectorAllInPage)('[role="row"] input', page);
        const result = await SUT.getHandlesWithRole('foo bar', inputElements);
        // Then
        expect(inputElements.length).toBe(8);
        expect(result.length).toBe(2);
        await browser.close();
    });
    test('should return no elements when role is not found', async () => {
        // Given
        const browser = await playwright_1.chromium.launch({ headless: true });
        const browserContext = await browser.newContext({ viewport: null });
        const page = await browserContext.newPage();
        const url = `file:${path.join(__dirname, 'get-handles-with-role.test.html')}`;
        await page.goto(url);
        // When
        const rootElements = await (0, page_actions_1.querySelectorAllInPage)('[role="row"] input', page);
        const result = await SUT.getHandlesWithRole('foobar', rootElements);
        // Then
        expect(rootElements.length).toBe(8);
        expect(result.length).toBe(0);
        await browser.close();
    });
});
